Learn R Programming

shotGroups (version 0.3)

DF300BLK: Combined bullet hole data

Description

Example of a data frame from one file with one group of bullet holes.

Usage

data(DF300BLK)

Arguments

Details

One group of shooting a Noveske AR-15 rifle in 300BLK at 100yd. The measurement unit for coordinates is inch, for distance yards. This data frame is like those returned by readDataOT1, readDataOT2, or readDataMisc with option combine=TRUE. Data courtesy of David Bookstaber, 2013. http://ballistipedia.com/

See Also

combineData, analyzeGroup, compareGroups

Examples

Run this code
data(DF300BLK)
str(DF300BLK)

Run the code above in your browser using DataLab