Learn R Programming

shotGroups (version 0.7.3)

DFlandy01: Combined bullet hole data

Description

Example of a data frame from one file with one group of bullet holes.

Usage

data(DFlandy01)

Arguments

Format

A data frame with 530 observations on the following 15 variables.

group

a numerical vector with group numbers 1 to 53.

distance

a numerical vector giving the distance to the target.

aim.x

a numerical vector of x-coordinates giving the point of aim.

aim.y

a numerical vector of y-coordinates giving the of point of aim.

point.x

a numerical vector of absolute x-coordinates of bullet holes.

point.y

a numerical vector of absolute y-coordinates of bullet holes.

ammunition

a character vector giving ammunition and lot number.

velocity

a numerical vector of chronograph readings in ft/s.

control

undocumented.

phase1

undocumented.

phase2

undocumented.

file

a character vector with the original file name.

groupVerb

a character vector designating the group by combining the original file name and ammunition.

series

a character vector that codes each separate group in an alternative way.

seriesNum

like series but numeric.

Details

53 groups with 10 shots each of .22LR shot at Eley test center on Oct 2 2016 using a Stiller 2500X action at a distance of 50m. The measurement unit for coordinates is mm, for distance m. This data frame is like those returned by readDataOT1, readDataOT2, or readDataMisc with option combine=TRUE. Data courtesy of Larry Landercasper, 2017. Analyzed by Albert Highe: http://www.rimfireaccuracy.com/Forums/showthread.php/10397-Fun-with-Probabilities

See Also

combineData, analyzeGroup, compareGroups

Examples

Run this code
# NOT RUN {
data(DFlandy01)
str(DFlandy01)
# }

Run the code above in your browser using DataLab