A data frame with 100 observations on the following 12 variables.
groupa numerical vector with group numbers 1, 2.
distancea numerical vector giving the distance to the target.
aim.xa numerical vector of x-coordinates giving the point of aim.
aim.ya numerical vector of y-coordinates giving the of point of aim.
point.xa numerical vector of absolute x-coordinates of bullet holes.
point.ya numerical vector of absolute y-coordinates of bullet holes.
ammunitiona character vector giving ammunition and lot number.
velocitya numerical vector of chronograph readings in ft/s.
filea character vector with the original file name.
groupVerba character vector designating the group by combining the original file name and ammunition.
seriesa character vector that codes each separate group in an alternative way.
seriesNumlike series but numeric.