Learn R Programming

shotGroups (version 0.3)

fromMOA: Conversion from minutes of angle

Description

Converts MOA (minutes of angle) to object size.

Usage

fromMOA(x, dst, conversion = 'm2cm')

Arguments

x
a numerical vector of MOA values.
dst
a numerical vector of viewing distances.
conversion
how to convert the measurement unit for distance to target to that of the (x,y)-coordinates. Either a character vector indicating the conversion like 'm2cm' for meter to centimeter, 'yd2in' for yards to inches, or 'ft2cm'

Value

  • A numerical vector with the object sizes. The measurement unit is determined by conversion.

See Also

getMOA

Examples

Run this code
objMOA <- seq(10, 30, by=5)
objDst <- 25                  # m
fromMOA(objMOA, dst=objDst, conversion='m2cm')

## this should return objMOA
getMOA(fromMOA(objMOA, objDst, conversion='m2cm'),
       objDst, conversion='m2cm')

Run the code above in your browser using DataLab