Learn R Programming

shotGroups (version 0.3)

getDistToCtr: Distances to center for a set of points

Description

Calculates the distances of a set of points to their center.

Usage

getDistToCtr(xy)

## S3 method for class 'data.frame':
getDistToCtr(xy)

## S3 method for class 'default':
getDistToCtr(xy)

Arguments

xy
either a numerical (n x p)-matrix with the coordinates of n points in p-dimensional space (1 row of coordinates per point), or a data frame with either the variables X, Y or Point.X, Point.Y.

Value

  • A numerical vector with the distances from each point to the center of the set.

Details

No coordinate transforms are done (unlike in groupLocation, groupShape, groupSpread), i.e., origin is not assumed to be in top-left corner, and points are not taken relative to point of aim.

Examples

Run this code
# coordinates given by a suitable data frame
getDistToCtr(DFtalon)

# coordinates given by a matrix
xy <- matrix(round(rnorm(20, 100, 15), 1), ncol=2)
getDistToCtr(xy)

Run the code above in your browser using DataLab