Usage
groupLocation(xy, level = 0.95, plots = c('0', '1', '2'), dstTarget = 100,
conversion = 'm2cm', target = c('BDS25m', 'DSB25m'), caliber=9)
## S3 method for class 'data.frame':
groupLocation(xy, level = 0.95, plots = c('0', '1', '2'), dstTarget = 100,
conversion = 'm2cm', target = c('BDS25m', 'DSB25m'), caliber=9)
## S3 method for class 'default':
groupLocation(xy, level = 0.95, plots = c('0', '1', '2'), dstTarget = 100,
conversion = 'm2cm', target = c('BDS25m', 'DSB25m'), caliber=9)Arguments
xy
either a numerical (n x 2)-matrix with the (x,y)-coordinates of n points (1 row of coordinates per point), or a data frame with either the variables X, Y or Point.X, Point.Y as well as Aim.X
level
a numerical value giving the level for the confidence intervals for the center (x,y)-coordinates.
plots
a numerical value indicating whether a 2D-scatterplot should be shown. 0: no plot, 1: regular scatterplot, 2: scatterplot with added target in the background (this feature is incomplete and experimental).
dstTarget
a numerical value giving the distance to the target - used in MOA calculation. See getMOA. conversion
how to convert the measurement unit for distance to target to that of the (x,y)-coordinates - used in MOA calculation. See getMOA. target
a character string indicating the target type to be drawn in the scatterplot. Currently, only two types of pistol targets are supported.
caliber
a numerical value indicating the bullet diameter in mm. Only used with plots='2'.