groupShape(xy, plots = TRUE, bandW = 0.5, outlier=c('mcd', 'pca'), ...)
## S3 method for class 'data.frame':
groupShape(xy, plots = TRUE, bandW = 0.5, outlier=c('mcd', 'pca'), ...)
## S3 method for class 'default':
groupShape(xy, plots = TRUE, bandW = 0.5, outlier=c('mcd', 'pca'), ...)X, Y or Point.X, Point.Y as well as Aim.Xbandwith of smoothScatter.mcd uses robust Mahalanobis distances (see aq.plot), pca uses robust principal components analysis (see pcout with outlier='pca' - final sensitivity can be adjusted with option outbound, a sensible candidate value seems to be around 0.45.aq.plotchisq.plot, including a reference line with intercept 0 and slope 1smoothScattertogether with group center and error ellipse based on a robust estimate for the covariance matrixqqnorm,
smoothScatter,
hist,
kernel,
covMcd,
shapiro.test,
mvnorm.etest,
chisq.plot,
aq.plot,
pcout# coordinates given by a suitable data frame
res <- groupShape(DFsavage, bandW=4, outlier='mcd')
names(res)
res$corXY
res$Outliers
res$multNorm
# coordinates given by a matrix
xy <- matrix(round(rnorm(200, 0, 5), 2), ncol=2)
groupShape(xy, bandW=1.6)Run the code above in your browser using DataLab