compareGroups(DF, plots = TRUE, xyTopLeft = TRUE,
ABalt = c('two.sided', 'less', 'greater'),
Walt = c('two.sided', 'less', 'greater'),
conversion = 'm2cm')Series (a factor), and either Point.X, Point.Y or X, Y defining the bullet holes. VariablegetMOA.Group variable identifies groups just within one file, whereas factor Series is taken to number groups also across different original files. If your data was read with readDataOT1, readDataOT2 or readDataMisc, Series is added automatically. Otherwise, you can just copy variable Groups to Series in a data frame called shots with shots$Series <- shots$Group.
If the data is missing information about the point of aim, (0,0) is assumed. If distance to target is missing, 100 is assumed.
In addition to the numerical results listed below, this function produces the following diagrams:
analyzeGroup,
getDistToCtr,
getMaxPairDist,
getMinBBox,
getMinCircle,
getCEP,
getMOA,
getRayParam,
drawEllipse,
anova.mlm,
ansari_test,
fligner_test,
wilcox_test,
kruskal_testdata(DFinch)
# select only first 2 series
DFsub <- subset(DFinch, Series %in% 2:3)
cmp <- compareGroups(DFsub, conversion='yd2in')
names(cmp)
cmp$ctr
cmp$meanDistToCtr
cmp$CEPray
cmp$WilcoxonRun the code above in your browser using DataLab