The shotGroups package provides functions to read in, plot, statistically describe, analyze, and compare shot group data with respect to group shape, precision, and accuracy. This includes graphical methods, descriptive statistics, and inference tests using standard, but also nonparametric and robust statistical methods. The data can be imported from files produced by OnTarget PC and OnTarget TDS or from custom data files in text format with a similar structure.
Arguments
Details
ll{
Package: shotGroups
Type: Package
Version: 0.3
Date: 2014-01-08
Depends: R (>= 2.12), boot
Imports: coin, energy, graphics, grDevices, mvoutlier, robustbase, stats, KernSmooth
License: GPL (>= 2)
}
Use help(package='shotGroups') for a list of all functions and links to the detailed help pages with information on options, usage and output. For further explanantions and an example walkthrough, see vignette('shotGroups'). A good description of statistical techniques for shot group analysis can be found at
http://ballistipedia.com/.